@@ -17,7 +17,7 @@ class Test7z:
 
     @pytest.mark.complete("7z x ", cwd="7z")
     def test_4(self, completion):
-        assert completion == "a.7z"
+        assert completion == "a.7z hello.7z.001".split()
 
     @pytest.mark.complete("7z d a.7z ", cwd="7z", require_cmd=True)
     def test_5(self, completion):
@@ -25,7 +25,9 @@ class Test7z:
 
     @pytest.mark.complete("7z a -air@", cwd="7z")
     def test_6(self, completion):
-        assert completion == sorted("-air@a.7z -air@f.txt".split())
+        assert completion == sorted(
+            "-air@a.7z -air@hello.7z.001 -air@hello.7z.002 -air@f.txt".split()
+        )
 
     @pytest.mark.complete("7z a -o")
     def test_7(self, completion):
