@@ -2,6 +2,6 @@ import pytest
 
 
 class TestEnscript:
-    @pytest.mark.complete("enscript --")
+    @pytest.mark.complete("enscript --", require_cmd=True)
     def test_1(self, completion):
         assert completion
