@@ -2,8 +2,8 @@ import pytest
 
 
 class TestMunindoc:
-
     # Assume at least munin* available
-    @pytest.mark.complete("munindoc m")
+    # require_cmd is not strictly correct here, but...
+    @pytest.mark.complete("munindoc m", require_cmd=True)
     def test_1(self, completion):
         assert completion
