@@ -11,7 +11,7 @@ class TestUnitVariables:
         assert_bash_exec(
             bash, "unset assoc2 && declare -A assoc2=([idx1]=1 [idx2]=2)"
         )
-        assert_bash_exec(bash, "unset ${!___v*} && declare ___var=''")
+        assert_bash_exec(bash, 'unset ${!___v*} && declare ___var=""')
         request.addfinalizer(
             lambda: assert_bash_exec(bash, "unset ___var assoc1 assoc2")
         )
@@ -28,6 +28,10 @@ class TestUnitVariables:
     def test_multiple_array_indexes(self, functions, completion):
         assert completion == "${assoc2[idx1]} ${assoc2[idx2]}".split()
 
+    @pytest.mark.complete(": ${assoc2[", shopt=dict(failglob=True))
+    def test_multiple_array_indexes_failglob(self, functions, completion):
+        assert completion == "${assoc2[idx1]} ${assoc2[idx2]}".split()
+
     @pytest.mark.complete(": ${assoc1[bogus]")
     def test_closing_curly_after_square(self, functions, completion):
         assert completion == "}"
